@@ -65,6 +65,10 @@ class Geo_common:
             # 判断R1和R2是否对应
             r1s = self.samples[line[0]]["raw_file_r1"]
             r2s = self.samples[line[0]]["raw_file_r2"]
+            if type(r1s) != list:
+                r1s = r1s.split()
+            if type(r2s) != list:
+                r2s = r2s.split()
             if len(r1s) != len(r2s):
                 exit("错误: %s 的R1和R2文件数量不相等" %(line[0]))
             l1 = 0                                                      # read测序长度, 只取R1的第一个数据
